pub enum ClippingMode {
Soft,
SoftWithMask,
Hard,
}Expand description
Modes of clipping that can be applied to reads
Variants
Soft
Soft clip: convert bases to S operators in CIGAR, keep bases and qualities
SoftWithMask
Soft clip with masking: convert to S operators and mask bases to N, qualities to min
Hard
Hard clip: remove bases, qualities, and convert to H operators in CIGAR