CodecConsensusOptions

Struct CodecConsensusOptions 

pub struct CodecConsensusOptions {
Show 15 fields pub min_input_base_quality: u8, pub error_rate_pre_umi: u8, pub error_rate_post_umi: u8, pub min_reads_per_strand: usize, pub max_reads_per_strand: Option<usize>, pub min_duplex_length: usize, pub single_strand_qual: Option<u8>, pub outer_bases_qual: Option<u8>, pub outer_bases_length: usize, pub max_duplex_disagreements: usize, pub max_duplex_disagreement_rate: f64, pub cell_tag: Option<Tag>, pub produce_per_base_tags: bool, pub trim: bool, pub min_consensus_base_quality: u8,
}
Options for CODEC consensus calling

Fields

min_input_base_quality: u8

Minimum base quality to include in consensus

error_rate_pre_umi: u8

Pre-UMI error rate (Phred scale)

error_rate_post_umi: u8

Post-UMI error rate (Phred scale)

min_reads_per_strand: usize

Minimum number of read pairs required to form consensus per strand

max_reads_per_strand: Option<usize>

Maximum number of read pairs to use per strand (downsample if exceeded)

min_duplex_length: usize

Minimum duplex overlap length (in bases)

single_strand_qual: Option<u8>

Reduce quality of single-strand regions to this value (if set)

outer_bases_qual: Option<u8>

Reduce quality of outer bases to this value (if set)

outer_bases_length: usize

Number of outer bases to reduce quality for

max_duplex_disagreements: usize

Maximum number of duplex disagreements allowed

max_duplex_disagreement_rate: f64

Maximum duplex disagreement rate allowed (0.0-1.0)

cell_tag: Option<Tag>

Cell barcode tag (e.g., “CB”)

produce_per_base_tags: bool

Whether to produce per-base tags (ad, ae, bd, be, etc.)

trim: bool

Whether to quality-trim reads before consensus calling

min_consensus_base_quality: u8

Minimum consensus base quality (output bases below this are masked to N)