DisagreementStrategy

Enum DisagreementStrategy 

pub enum DisagreementStrategy {
    Consensus,
    MaskBoth,
    MaskLowerQual,
}
Strategy for handling bases that disagree in overlapping regions

Variants



Consensus

Call the base with higher quality, new qual = qual_high - qual_low



MaskBoth

Mask both bases to N with quality 2



MaskLowerQual

Mask only the lower quality base to N with quality 2