FilterResult

Enum FilterResult 

pub enum FilterResult {
    Pass,
    InsufficientReads,
    ExcessiveErrorRate,
    LowQuality,
    TooManyNoCalls,
}
Result of filtering a consensus read

Variants



Pass

Read passed all filters



InsufficientReads

Read failed minimum reads threshold



ExcessiveErrorRate

Read failed maximum error rate threshold



LowQuality

Read failed minimum mean base quality threshold



TooManyNoCalls

Read failed maximum no-call fraction threshold

Implementations

Source

impl FilterResult

pub fn to_rejection_reason(&self) -> Option<RejectionReason>

Converts a FilterResult to a RejectionReason, if rejected.

Returns None if the result is Pass, otherwise returns the corresponding rejection reason for tracking in metrics and logging.