#[repr(C)]pub struct TemplateInlineHeader {
pub key: TemplateKey,
pub record_len: u32,
pub padding: u32,
}Expand description
Inline header stored before each record in the data buffer. This allows us to use a minimal ref structure while still having fast access to the full sort key.
Layout (40 bytes total):
- primary: 8 bytes (u64)
- secondary: 8 bytes (u64)
- tertiary: 8 bytes (u64)
name_hash_upper: 8 bytes (u64)record_len: 4 bytes (u32)- padding: 4 bytes (u32)
Fields
key: TemplateKeyFull sort key for comparison.
record_len: u32Length of following raw BAM data.
padding: u32Padding for 8-byte alignment.
Implementations