pub struct BatchedSamReader<R: Read> { /* private fields */ }Expand description
Adaptive buffered reader for SAM input from bwa mem.
Reads bytes into a growable buffer, tracks batch boundaries like bwa, and grows the buffer based on observed batch sizes. Never shrinks.
Implementations
Sourceimpl<R: Read> BatchedSamReader<R>
impl<R: Read> BatchedSamReader<R>
Sourcepub fn new(reader: R, chunk_size: u64) -> Self
pub fn new(reader: R, chunk_size: u64) -> Self
Create a new reader with the given bwa chunk size (-K value).
Sourcepub fn fill_buffer(&mut self) -> Result<bool>
pub fn fill_buffer(&mut self) -> Result<bool>
Fill buffer by reading chunks until buffer is full or EOF.
Handles edge cases:
- Grows buffer proactively if unparsed data > 50% of capacity
- Preserves partial records at end of buffer
- Never loses data
Errors
Returns an error if the underlying reader fails.
Sourcepub fn record_parsed(&mut self, seq_len: usize, bytes_consumed: usize) -> bool
pub fn record_parsed(&mut self, seq_len: usize, bytes_consumed: usize) -> bool
Called after parsing a SAM record.
Tracks bases and records for batch detection. When a batch boundary is reached, may grow the buffer based on observed batch size.
Returns true if the buffer was grown.
Sourcepub fn advance(&mut self, bytes: usize)
pub fn advance(&mut self, bytes: usize)
Advance parse position without tracking as a record (e.g., for headers).
Sourcepub fn batches_completed(&self) -> usize
pub fn batches_completed(&self) -> usize
Get number of completed batches.
Sourcepub fn total_bytes_read(&self) -> usize
pub fn total_bytes_read(&self) -> usize
Get total bytes read from input.
Sourcepub fn chunk_size(&self) -> u64
pub fn chunk_size(&self) -> u64
Get the configured chunk size (bwa -K value).